@@ -15,9 +15,7 @@
 //qDebug() << "number:" << QString::number(signalnr);
 #include <QMaemo5InformationBox>
 #include <QSystemDeviceInfo>
-
-QTM_USE_NAMESPACE
-//using namespace QtMobility;
+using namespace QtMobility;
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -330,10 +328,13 @@ void MainWindow::refresh_filter()
 //####Local#####
 void MainWindow::on_tabWidget_local_currentChanged(int index)
 {
-    if (index==4) {
+    if (index==3) {
+        sshstatus();
+    }
+    else if (index==4) {
         refresh_filter();
     }
-    if (index==5) {
+    else if (index==5) {
         ui->textEdit_lsof->clear();
         ui->textEdit_lsof->setGeometry(9,9,709,319);
         ui->textEdit_lsof->setMinimumSize(0,0);
@@ -1792,6 +1793,11 @@ void MainWindow::on_tabWidget_route_currentChanged(int index)
         ui->textEdit_routet->setText(tmp);
     }
     else if (index==3) {
+        wload_ini();
+        checkwmode();
+        wifistatus();
+    }
+    else if (index==4) {
         getrev();
         getos();
         getkernel();
@@ -1999,3 +2005,153 @@ void MainWindow::getrev()
     ui->textEdit_3->append(list.at(i));
     }*/
 }
+
+void MainWindow::on_pushButton_wsave_clicked()
+{
+    QSettings settings("/home/user/.genwall/network.ini", QSettings::IniFormat);
+    settings.beginGroup("Wifi");
+    settings.setValue("wip", ui->lineEdit_wip->text());
+    settings.setValue("wnetm", ui->lineEdit_wnetmask->text());
+    settings.setValue("wdhcp1", ui->lineEdit_wdhcprange1->text());
+    settings.setValue("wdhcp2", ui->lineEdit_wdhcprange2->text());
+    settings.setValue("wessid", ui->lineEdit_wessid->text());
+    settings.setValue("wpass", ui->lineEdit_wpassword->text());
+    settings.setValue("wch", ui->spinBox_wchannel->value());
+    settings.endGroup();
+    QMaemo5InformationBox::information(this, "settings saved",
+                                                QMaemo5InformationBox::DefaultTimeout);
+}
+
+
+void MainWindow::on_pushButton_wstartstop_clicked()
+{
+    QProcess *process = new QProcess(this);
+    process->start("/opt/genwall/wifi.sh");
+    process->waitForFinished();
+    checkwmode();
+    wifistatus();
+}
+
+void MainWindow::on_pushButton_wadhoc_clicked()
+{
+    QFileInfo fi("/home/user/.genwall/network.ini");
+    if (!fi.exists()) QMaemo5InformationBox::information(this, "please save wifi settings first!", QMaemo5InformationBox::DefaultTimeout);
+    else {
+    if (checkmodule("wl12xx")==true)
+    {
+
+        QProcess *process = new QProcess(this);
+        if (wmode("wlan0")==false)
+        {
+            if (ui->radioButton_wdnslan->isChecked()) process->start("/opt/genwall/hotspot.sh lan");
+            else if (ui->radioButton_wdnsfor->isChecked()) process->start("/opt/genwall/hotspot.sh for");
+            else if (ui->radioButton_wdnsnone->isChecked()) process->start("/opt/genwall/hotspot.sh");
+        }
+        else process->start("/opt/genwall/hotspot_off.sh");
+        process->waitForFinished();
+        checkwmode();
+     }
+    else QMaemo5InformationBox::information(this, "start wifi first", QMaemo5InformationBox::DefaultTimeout);
+    }
+}
+
+void MainWindow::wload_ini()
+{
+    QFileInfo fi("/home/user/.genwall/network.ini");
+    if (!fi.exists()){
+        QMaemo5InformationBox::information(this, "no file found", QMaemo5InformationBox::DefaultTimeout);
+    }
+    else {
+            QSettings settings("/home/user/.genwall/network.ini", QSettings::IniFormat);
+            settings.beginGroup("Wifi");
+            ui->lineEdit_wip->setText(settings.value("wip").toString());
+            ui->lineEdit_wnetmask->setText(settings.value("wnetm").toString());
+            ui->lineEdit_wdhcprange1->setText(settings.value("wdhcp1").toString());
+            ui->lineEdit_wdhcprange2->setText(settings.value("wdhcp2").toString());
+            ui->lineEdit_wessid->setText(settings.value("wessid").toString());
+            ui->lineEdit_wpassword->setText(settings.value("wpass").toString());
+            ui->spinBox_wchannel->setValue(settings.value("wch").toInt());
+            settings.endGroup();
+            //QMaemo5InformationBox::information(this, "settings loaded", QMaemo5InformationBox::DefaultTimeout);
+        }
+    }
+void MainWindow::sshstatus()
+{
+    QString prog = "sh";//shell
+    QStringList arguments;
+    arguments << "-c" << "/opt/genwall/ssh-status.sh check";
+    QProcess* process = new QProcess(this);
+    process->start(prog, arguments);
+    process->waitForFinished();
+    int code=process->exitCode();
+    //QString tmp=process->readAll();
+    if (code==0) {
+        ui->label_sshstatus->setText("running");
+        ui->label_sshstatus->setStyleSheet("QLabel { background-color : green; }");
+    }
+    else {
+        ui->label_sshstatus->setText("off");
+        ui->label_sshstatus->setStyleSheet("QLabel { background-color : red; }");
+    }
+}
+
+void MainWindow::on_pushButton_sshstartstop_clicked()
+{
+    ui->label_sshstatus->setStyleSheet("QLabel { background-color : green; }");
+    QString prog = "sh";//shell
+    QStringList arguments;
+    arguments << "-c" << "/opt/genwall/ssh-status.sh change";
+    QProcess* process = new QProcess(this);
+    process->start(prog, arguments);
+    process->waitForFinished();
+    sshstatus();
+}
+
+bool MainWindow::wmode(QString dev)
+{
+    QString prog = "sh";//shell
+    //QString prog = "/sbin/ifconfig";
+    QStringList arguments;
+    arguments << "-c" << "/sbin/iwconfig " + dev + " | grep \"Mode:\" | awk '{print $1}' | sed 's/Mode://'";
+    QProcess* process = new QProcess(this);
+    process->start(prog, arguments);
+    process->waitForFinished();
+    QString tmp=process->readAll();
+    tmp=tmp.left(tmp.count()-1);
+    if (tmp=="Ad-Hoc") return true;
+    else return false;
+}
+
+void MainWindow::checkwmode()
+{
+    if (wmode("wlan0")==true) ui->pushButton_wadhoc->setStyleSheet("QPushButton { background-color : green; }");
+    else ui->pushButton_wadhoc->setStyleSheet("QPushButton { background-color : red; }");
+}
+bool MainWindow::checkmodule(QString nmodule)
+{
+    bool test;
+    test=false;
+    QFile file("/proc/modules");
+    if(!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        QMessageBox::information(0, "error", file.errorString());
+    }
+    QTextStream in(&file);
+        QString line = in.readLine();
+        while (!line.isNull()) {
+            if (line.contains(nmodule)==true)
+            {
+                test=true;
+                break;
+            }
+            line = in.readLine();
+    }
+    file.close();
+    if (test==true) return true;
+    else return false;
+}
+
+void MainWindow::wifistatus()
+{
+    if (checkmodule("wl12xx")==true) ui->pushButton_wstartstop->setStyleSheet("QPushButton { background-color : green; }");
+    else ui->pushButton_wstartstop->setStyleSheet("QPushButton { background-color : red; }");
+}
