@@ -26,6 +26,7 @@ protected:
 private slots:
     void save_ini();
     void load_ini();
+    void wload_ini();
     void on_pushButton_rulenow_clicked();
     void on_listWidget_real_doubleClicked(QModelIndex index);
     int runtime_filter(QString);
@@ -74,6 +75,9 @@ private slots:
     void on_pushButton_savefport_clicked();
     void on_pushButton_loadloport_clicked();
     void on_pushButton_saveloport_clicked();
+    void checkwmode();
+    void wifistatus();
+    bool checkmodule(QString nmodule);
     int cuttercount(QString row);
     int cutterint(QString row, int place);
     QString getlsof();
@@ -81,8 +85,10 @@ private slots:
     QString filterlog(QString linelog);
     QString cutter(QString row, QString cutstr, int place);
     QString getip(QString dev);
+    bool wmode(QString dev);
     QString getfilter(QString ftype);
     QString getpidof(QString pname);
+    void sshstatus();
     void getrev();
     void getimei();
     void getimsi();
@@ -111,6 +117,10 @@ private slots:
     void on_pushButton_gwdel_clicked();
     void on_pushButton_routedefaultdel_clicked();
     void on_pushButton_resetdns_clicked();
+    void on_pushButton_wsave_clicked();
+    void on_pushButton_wstartstop_clicked();
+    void on_pushButton_wadhoc_clicked();
+    void on_pushButton_sshstartstop_clicked();
 };
 
 #endif // MAINWINDOW_H
